/*
Copyright (C) 2009 -  Claudio Salvadori 
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/**
 *\file Stream_enum.h
 *
 *\date  Created on: 29-apr-2009
 *\author  Author: Claudio Salvadori
 *\brief All enumeration used by the data reader
 */

#ifndef _STREAM__ENUM_H_
#define _STREAM__ENUM_H_

/**
*\brief Enumeration of possible result IStreamReader interface class method.
*/
enum s_ret{
	S_RET_OK		=	0,	/**<Ok*/
	
	S_OPTION_ERR		=	1, 	/**<Option struct doesn't fill correctly*/
	
	S_D_EMPTY_ERR		=	2, 	/**<Empty input buffer (decode)*/
	S_D_ESCAPE_ERR		=	3, 	/**<Escape character in the wrong position*/
	
	S_M_EMPTY_ERR		=	4, 	/**<Empty input buffer (divide in messages)*/
	S_M_LENGTH_ERR		=	5,	/**<Wrong packet size (divide in messages)*/ 
	
	S_F_OPEN_ERR		=	6,	/**<Error in file opening*/
	S_F_READ_ERR		=	7,	/**<Error in file reading*/
	S_F_R_LENGTH_ERR	=	8,	/**<Error: read shortest packet in file*/
	S_F_R_START_ERR		=	9, 	/**<Error in reading file: start character doesn't find*/
	S_F_R_END_ERR		=	10,	/**<Error in reading file: end character doesn't find*/
	S_F_EOS			=	11,	/**<OK end of stream for files*/
	
	S_S_PRESET_MISS_ERR	=	12,	/**<Error: missing the serial preset*/
	S_S_OPEN_ERR		=	13,  	/**<Error in serial open*/
	S_S_G_CHAR_ERR		=	14,	/**<Error: serial get char*/
	S_S_P_CHAR_ERR		=	15,	/**<Error: serial put char*/
	S_S_READ_ERR		=	16,  	/**<Error in receiving from serial*/
	S_S_WRITE_ERR		=	17, 	/**<Error in sending by serial*/
	S_S_LENGHT_ERR		=	18, 	/**<Error: read shortest/longest packet from serial*/
	S_S_R_TIMEOUT_ERR	=	19, 	/**<Error: serial receive timeout error*/
	S_S_T_TIMEOUT_ERR	=	20,	/**<Error: serial transmit timeout error*/
	S_S_NACK		=	21,	/**<Nack received during handshking (serial)*/
	S_S_GEN_ERR		=	22,	/**<Generic error(serial)*/
	
	S_P_INIT_ERR		=	23, 	/**<Error in pipe init*/
	S_P_G_CHAR_ERR		=	24, 	/**<Error: pipe get char*/
	S_P_P_CHAR_ERR		=	25,	/**<Error: pipe put char*/
	S_P_READ_ERR		=	26, 	/**<Error in receiving from pipe*/
	S_P_WRITE_ERR		=	27,	/**<Error in sending by pipe*/
	S_P_LENGHT_ERR		=	28, 	/**<Error: read shortest/longest packet from pipe*/
	S_P_R_TIMEOUT_ERR	=	29, 	/**<Error: pipe receive timeout error*/
	S_P_T_TIMEOUT_ERR	=	30,	/**<Error: pipe transmit timeout error*/
	S_P_NACK		=	31,	/**<Nack received during handshking (pipe)*/
	S_P_GEN_ERR		=	32, 	/**<Generic error(pipe)*/
	S_P_NOTIMPL		=	33,	/**<Not implemented*/

	S_SO_INIT_ERR		=	34,	/**<Error in initializing the socket*/
	S_SO_INIT_V_ERR		=	35,	/**<Error in initializing the socket(not correct version)*/
	S_SO_INIT_R_ERR		=	36,	/**<Error in initializing the socket(resolving server)*/
	S_SO_INIT_C_ERR		=	37,	/**<Error in initializing the socket(create socket error)*/
	S_SO_INIT_CONN_ERR	=	38,	/**<Error in initializing the socket(client connection error)*/
	S_SO_WRITE_ERR		=	39,	/**<Socket write error*/
	S_SO_LENGHT_ERR		=	40,	/**<Error: read shortest/longest packet from socket*/
	S_SO_NACK		=	41,	/**<Socket: Nack received during handshking*/
	S_SO_GEN_ERR		=	42, 	/**<Socket: Generic error*/
	S_SO_READ_ERR		=	43, 	/**<Socket read error*/
	S_SO_CLOSED_ERR		=	44, 	/**<Socket connection closed*/

	/**********************************************************************************************/
	/*        ADD HERE THE RETURN ERRORS FROM THE NEW COMMUNICATION DEVICE CLASS                  */
	/**********************************************************************************************/
};

/**
*\brief Style of reading.
*/
enum s_read_style{
	S_STYLE_LENGTH	=	0, 	/**<Reader based on the lenght*/
	S_STYLE_S_E	=	1, 	/**<Reader based on strart and end character*/
};



#endif
	
