//author Paolo Pagano (ReTiS lab, Pisa)

/*
Copyright (C) 2009 - Paolo Pagano and Claudio Salvadori
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/**
 * @file   DAQEvent.cpp
 * @author Paolo Pagano 
 * @date   Wed Jul  8 11:06:26 2009
 * 
 * @brief  DAQEvent.h functions development 
 * 
 * 
 */

/**
 * @file  DAQEventLinkDef.h
 * @brief Compiling directive to generate the dictionary
 * 
 * 
 */

/**
 * @file  DAQEventDict.h
 * @brief File generated by ROOT
 * 
 * 
 */

/**
 * @file  DAQEventDict.cpp
 * @brief File generated by ROOT
 * 
 * 
 */

/**
 * @file  ROOTInitializer.cpp 
 * @author Paolo Pagano 
 * @brief Static class to initialize the repository file.
 * 
 * 
 */

/**
 * @file   DAQEvent.h
 * @author Paolo Pagano 
 * @date   Wed Jul  8 11:06:26 2009
 * 
 * @brief  This file contains the class to acquire an event through the link
 */

#ifndef ROOT_DAQCombined
#define ROOT_DAQCombined

#include "DAQSData.h"

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// DAQEvent                                                             //
//                                                                      //
// Description of the event and DAQTimers parameters                    //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

/** \class TObject
 *\brief Base class in the ROOT framework for every serializable objects.*/

/** \class DAQEvent
 *\brief Class containing members and methods for a complete event acquired through the link*/
class DAQEvent : public TObject {

private:
	char           		fType[20];		/**< String containing the type of the event*/
	char          		*fDAQSDataName;      	/**< Run+event number in character format*/
	Int_t          		fNDAQSDatas;        	/**< Number of SData objects in the event*/
	TClonesArray  		*fDAQSDatas;        	/**< Array with all the events stored*/
	TRef           		fLastEvent;         	/**< reference pointer to last SData */
	static TClonesArray 	*fgDAQSDatas;		/**< static counterpart of fDAQSDatas */

public:
	DAQEvent();
	virtual ~DAQEvent();

	/** 
	* \brief build a new event
	* \param ev Event number
	* \param nsdata Number of SData
	* \param a Pointer to SData
	*/ 
	void          	Build(Int_t ev, std::vector< std::vector<SData> >* data);
	void          	Clear(Option_t *option ="");
	static void   	Reset(Option_t *option ="");
	char         	*GetType() {return fType;}
	void         	SetType(char *type) {strcpy(fType,type);}
	Int_t         	GetNDAQSDatas() const { return fNDAQSDatas; }
	TClonesArray 	*GetDAQSDatas() const {return fDAQSDatas;}
	DAQSData 	*AddDAQSData(std::vector<SData> sdata_);

	ClassDef(DAQEvent,1)  //DAQCombined structure
};

#endif
